@@ -23,7 +23,8 @@
 
 #include "my_decimal_limits.h"
 
-#define HOSTNAME_LENGTH 60
+#define HOSTNAME_LENGTH 255
+#define HOSTNAME_LENGTH_STR STRINGIFY_ARG(HOSTNAME_LENGTH)
 #define SYSTEM_CHARSET_MBMAXLEN 3
 #define NAME_CHAR_LEN	64              /* Field/table name length */
 #define USERNAME_CHAR_LENGTH 128
@@ -40,27 +41,6 @@
 #define MYSQL50_TABLE_NAME_PREFIX_LENGTH  (sizeof(MYSQL50_TABLE_NAME_PREFIX)-1)
 #define SAFE_NAME_LEN (NAME_LEN + MYSQL50_TABLE_NAME_PREFIX_LENGTH)
 
-/*
-  MDEV-4088
-
-  MySQL (and MariaDB 5.x before the fix) was using the first character of the
-  server version string (as sent in the first handshake protocol packet) to
-  decide on the replication event formats. And for 10.x the first character
-  is "1", which the slave thought comes from some ancient 1.x version
-  (ignoring the fact that the first ever MySQL version was 3.x).
-
-  To support replication to these old clients, we fake the version in the
-  first handshake protocol packet to start from "5.5.5-" (for example,
-  it might be "5.5.5-10.0.1-MariaDB-debug-log".
-
-  On the client side we remove this fake version prefix to restore the
-  correct server version. The version "5.5.5" did not support
-  pluggable authentication, so any version starting from "5.5.5-" and
-  claiming to support pluggable auth, must be using this fake prefix.
-*/
-/* this version must be the one that *does not* support pluggable auth */
-#define RPL_VERSION_HACK "5.5.5-"
-
 #define SERVER_VERSION_LENGTH 60
 #define SQLSTATE_LENGTH 5
 #define LIST_PROCESS_HOST_LEN 64
@@ -95,10 +75,10 @@
 #define LOCAL_HOST_NAMEDPIPE "."
 
 
-#if defined(__WIN__) && !defined( _CUSTOMCONFIG_)
+#if defined(_WIN32) && !defined( _CUSTOMCONFIG_)
 #define MYSQL_NAMEDPIPE "MySQL"
 #define MYSQL_SERVICENAME "MySQL"
-#endif /* __WIN__ */
+#endif
 
 /*
   You should add new commands to the end of this list, otherwise old
@@ -123,7 +103,7 @@ enum enum_server_command
   COM_SLAVE_WORKER=251,
   COM_SLAVE_IO=252,
   COM_SLAVE_SQL=253,
-  COM_MULTI=254,
+  COM_RESERVED_1=254, /* Old COM_MULTI, now removed */
   /* Must be last */
   COM_END=255
 };
@@ -179,7 +159,7 @@ enum enum_indicator_type
 #define NUM_FLAG	32768U		/* Field is num (for clients) */
 #define PART_KEY_FLAG	16384U		/* Intern; Part of some key */
 #define GROUP_FLAG	32768U		/* Intern: Group field */
-#define BINCMP_FLAG	131072U		/* Intern: Used by sql_yacc */
+#define CONTEXT_COLLATION_FLAG 131072U  /* Intern: Used by sql_yacc */
 #define GET_FIXED_FIELDS_FLAG (1U << 18) /* Used to get fields in item tree */
 #define FIELD_IN_PART_FUNC_FLAG (1U << 19)/* Field part of partition func */
 #define PART_INDIRECT_KEY_FLAG (1U << 20)
@@ -196,13 +176,13 @@ enum enum_indicator_type
 #define FIELD_FLAGS_COLUMN_FORMAT_MASK (3U << FIELD_FLAGS_COLUMN_FORMAT)
 #define FIELD_IS_DROPPED (1U << 26)     /* Intern: Field is being dropped */
 
-#define VERS_SYS_START_FLAG (1 << 27)   /* autogenerated column declared with
+#define VERS_ROW_START (1 << 27)   /* autogenerated column declared with
                                              `generated always as row start`
                                               (see II.a SQL Standard) */
-#define VERS_SYS_END_FLAG (1 << 28)     /* autogenerated column declared with
+#define VERS_ROW_END (1 << 28)     /* autogenerated column declared with
                                            `generated always as row end`
                                             (see II.a SQL Standard).*/
-#define VERS_SYSTEM_FIELD (VERS_SYS_START_FLAG | VERS_SYS_END_FLAG)
+#define VERS_SYSTEM_FIELD (VERS_ROW_START | VERS_ROW_END)
 #define VERS_UPDATE_UNVERSIONED_FLAG (1 << 29) /* column that doesn't support
                                                 system versioning when table
                                                 itself supports it*/
@@ -280,7 +260,7 @@ enum enum_indicator_type
 #define CLIENT_DEPRECATE_EOF (1ULL << 24)
 
 #define CLIENT_PROGRESS_OBSOLETE  (1ULL << 29)
-#define CLIENT_SSL_VERIFY_SERVER_CERT (1ULL << 30)
+#define CLIENT_SSL_VERIFY_SERVER_CERT_OBSOLETE (1ULL << 30)
 /*
   It used to be that if mysql_real_connect() failed, it would delete any
   options set by the client, unless the CLIENT_REMEMBER_OPTIONS flag was
@@ -296,13 +276,18 @@ enum enum_indicator_type
 #define MARIADB_CLIENT_FLAGS_MASK 0xffffffff00000000ULL
 /* Client support progress indicator */
 #define MARIADB_CLIENT_PROGRESS (1ULL << 32)
-/* support COM_MULTI */
-#define MARIADB_CLIENT_COM_MULTI (1ULL << 33)
+
+/* Old COM_MULTI experiment (functionality removed).*/
+#define MARIADB_CLIENT_RESERVED_1 (1ULL << 33)
+
 /* support of array binding */
 #define MARIADB_CLIENT_STMT_BULK_OPERATIONS (1ULL << 34)
 /* support of extended metadata (e.g. type/format information) */
 #define MARIADB_CLIENT_EXTENDED_METADATA (1ULL << 35)
 
+/* Do not resend metadata for prepared statements, since 10.6*/
+#define MARIADB_CLIENT_CACHE_METADATA (1ULL << 36)
+
 #ifdef HAVE_COMPRESS
 #define CAN_CLIENT_COMPRESS CLIENT_COMPRESS
 #else
@@ -333,7 +318,6 @@ enum enum_indicator_type
                            CLIENT_MULTI_STATEMENTS | \
                            CLIENT_MULTI_RESULTS | \
                            CLIENT_PS_MULTI_RESULTS | \
-                           CLIENT_SSL_VERIFY_SERVER_CERT | \
                            CLIENT_REMEMBER_OPTIONS | \
                            MARIADB_CLIENT_PROGRESS | \
                            CLIENT_PLUGIN_AUTH | \
@@ -341,19 +325,17 @@ enum enum_indicator_type
                            CLIENT_SESSION_TRACK |\
                            CLIENT_DEPRECATE_EOF |\
                            CLIENT_CONNECT_ATTRS |\
-                           MARIADB_CLIENT_COM_MULTI |\
                            MARIADB_CLIENT_STMT_BULK_OPERATIONS |\
                            MARIADB_CLIENT_EXTENDED_METADATA|\
+                           MARIADB_CLIENT_CACHE_METADATA |\
                            CLIENT_CAN_HANDLE_EXPIRED_PASSWORDS)
-
 /*
   Switch off the flags that are optional and depending on build flags
   If any of the optional flags is supported by the build it will be switched
   on before sending to the client during the connection handshake.
 */
-#define CLIENT_BASIC_FLAGS (((CLIENT_ALL_FLAGS & ~CLIENT_SSL) \
-                                               & ~CLIENT_COMPRESS) \
-                                               & ~CLIENT_SSL_VERIFY_SERVER_CERT)
+#define CLIENT_BASIC_FLAGS ((CLIENT_ALL_FLAGS & ~CLIENT_SSL) \
+                                               & ~CLIENT_COMPRESS)
 
 enum mariadb_field_attr_t
 {
@@ -474,7 +456,7 @@ typedef struct st_net {
   char net_skip_rest_factor;
   my_bool thread_specific_malloc;
   unsigned char compress;
-  my_bool unused3; /* Please remove with the next incompatible ABI change. */
+  my_bool pkt_nr_can_be_reset;
   /*
     Pointer to query object in query cache, do not equal NULL (0) for
     queries in cache that have not stored its results yet
